/**
 * 
 */
package edu.illinois.ncsa.paw.domain;

import java.util.List;
import java.util.Map;

import javax.persistence.CascadeType;
import javax.persistence.CollectionTable;
import javax.persistence.Column;
import javax.persistence.ElementCollection;
import javax.persistence.Entity;
import javax.persistence.FetchType;
import javax.persistence.JoinTable;
import javax.persistence.OneToMany;

import edu.illinois.ncsa.domain.AbstractBean;
import edu.illinois.ncsa.domain.Dataset;

/**
 * Configuration of a visualization of data output by a workflow using
 * specific web viewers.
 * 
 * @author Luigi Marini
 * 
 */
@Entity(name = "VisualizationConfiguration")
public class VisualizationConfiguration extends AbstractBean {

    /** Pretty name **/
    private String                       title;

    /** Long description **/
    private String                       description;

    /** Id of widget to instantiate in web UI **/
    private String                       widgetId;

    /** Datasets to visualize **/
    @OneToMany(fetch = FetchType.LAZY, cascade = { CascadeType.MERGE })
    @JoinTable(name = "VisualizationConfigurationDatasets")
    private List<Dataset>                datasets;

    /** Used for serialization of object */
    private static final long            serialVersionUID = 1L;

    /**
     * Map from visualization widget parameter to workflow parameter used to
     * configure visualization widget
     **/
    @ElementCollection
    @Column(name = "parameter")
    @CollectionTable(name = "VisualizationConfigurationParametersMap")
    private Map<String, MarkedParameter> parametersMap;

    public VisualizationConfiguration() {}

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public String getWidgetId() {
        return widgetId;
    }

    public void setWidgetId(String widgetId) {
        this.widgetId = widgetId;
    }

    public List<Dataset> getDatasets() {
        return datasets;
    }

    public void setDatasets(List<Dataset> dataSets) {
        this.datasets = dataSets;
    }

    public Map<String, MarkedParameter> getParametersMap() {
        return parametersMap;
    }

    public void setParametersMap(Map<String, MarkedParameter> parameters) {
        this.parametersMap = parameters;
    }
}
